Module gfapi_sys::gluster
[−]
[src]
Structs
| DirEntry | |
| DirEntryPlus | |
| Gluster | |
| GlusterDirectory | |
| GlusterDirectoryPlus |
This uses readdirplus which is very efficient in Gluster. In addition to returning directory entries this also stats each file. |
Enums
| GlusterError |
Custom error handling for the library |
| GlusterLogLevel |
None to Trace correspond to the equivalent gluster log levels |
| PosixLockCmd |
Apply or remove an advisory lock on the open file. |