Enum gfapi_sys::gluster::GlusterLogLevel [] [src]

#[repr(i32)]
pub enum GlusterLogLevel { None, Emerg, Alert, Critical, Error, Warning, Notice, Info, Debug, Trace, }

None to Trace correspond to the equivalent gluster log levels

Variants