Struct gfapi_sys::gluster::Gluster [] [src]

pub struct Gluster { /* fields omitted */ }

Methods

impl Gluster
[src]

[src]

Connect to a Ceph cluster and return a connection handle glfs_t port is usually 24007 but may differ depending on how the service was configured

[src]

Disconnect from a Gluster cluster and destroy the connection handle For clean up, this is only necessary after connect() has succeeded. Normally there is no need to call this function. When Rust cleans up the Gluster struct it will automatically call disconnect

[src]

This function specifies logging parameters for the virtual mount. Sets the log file to write to

[src]

Get the volfile associated with the virtual mount Sometimes it's useful e.g. for scripts to see the volfile, so that they can parse it and find subvolumes to do things like split-brain resolution or custom layouts. Note that the volume must be started (not necessarily mounted) for this to work. Also this function isn't very useful at the moment. It needs to be parsed into a volume graph before it's really usable.

[src]

Fetch the volume uuid from the glusterd management server

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

Read into fill_buffer at offset and return the number of bytes read

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

Tests for the existance of a file. Returns true/false respectively.

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

Removes a directory at this path, after removing all its contents. Use carefully!

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

times[0] specifies the new "last access time" (atime); times[1] specifies the new "last modification time" (mtime).

[src]

times[0] specifies the new "last access time" (atime); times[1] specifies the new "last modification time" (mtime).

[src]

times[0] specifies the new "last access time" (atime); times[1] specifies the new "last modification time" (mtime).

[src]

[src]

[src]

[src]

[src]

[src]

[src]