Enum gfapi_sys::gluster::PosixLockCmd
[−]
[src]
pub enum PosixLockCmd {
Exclusive,
Shared,
Unlock,
}Apply or remove an advisory lock on the open file.
Variants
ExclusivePlace an exclusive lock. Only one process may hold an exclusive lock for a given file at a given time.
Place a shared lock. More than one process may hold a shared lock for a given file at a given time.
UnlockRemove an existing lock held by this process.